/******************************************************************************
 * @file      : NUC1xx_i2c_master.h
 * @brief     : NUC1xx I2C Slave Peripheral Interface
 * @version	  : V1.0
 * @date      : 30. Jun. 2010
 * @author    : CooCox
******************************************************************************/
#include "stdio.h"
#include "NUC1xx.h"
#include "cox_types.h"
#include "cox_i2c_slave.h"
#include "NUC1xx_i2c_slave.h"
#define I2C_STAT_CODE_BITMASK           ((0xF8))
static SI2C_Setup_Cfg i2c_slave_cfg[2];
uint8_t  DataLen1 = 0;
#define E_DRVI2C_ERR_ARGUMENT   _SYSINFRA_ERRCODE(TRUE, MODULE_ID_DRVI2C, 1)
/** No relevant information */
#define I2C_I2STAT_NO_INF               ((0xF8))

/* Slave receive mode -------------------------------------------- */
/** Own slave address has been received, ACK has been returned */
#define I2C_I2STAT_S_RX_SLAW_ACK				((0x60))

/** Arbitration lost in SLA+R/W as master */
#define I2C_I2STAT_S_RX_ARB_LOST_M_SLA			((0x68))
/** Own SLA+W has been received, ACK returned */
//#define I2C_I2STAT_S_RX_SLAW_ACK				((0x68))

/** General call address has been received, ACK has been returned */
#define I2C_I2STAT_S_RX_GENCALL_ACK				((0x70))

/** Arbitration lost in SLA+R/W (GENERAL CALL) as master */
#define I2C_I2STAT_S_RX_ARB_LOST_M_GENCALL		((0x78))
/** General call address has been received, ACK has been returned */

/** Previously addressed with own SLV address;
 * Data has been received, ACK has been return */
#define I2C_I2STAT_S_RX_PRE_SLA_DAT_ACK			((0x80))
/** Previously addressed with own SLA;
 * Data has been received and NOT ACK has been return */
#define I2C_I2STAT_S_RX_PRE_SLA_DAT_NACK		((0x88))
/** Previously addressed with General Call;
 * Data has been received and ACK has been return */
#define I2C_I2STAT_S_RX_PRE_GENCALL_DAT_ACK		((0x90))
/** Previously addressed with General Call;
 * Data has been received and NOT ACK has been return */
#define I2C_I2STAT_S_RX_PRE_GENCALL_DAT_NACK	((0x98))
/** A STOP condition or repeated START condition has
 * been received while still addressed as SLV/REC
 * (Slave Receive) or SLV/TRX (Slave Transmit) */
#define I2C_I2STAT_S_RX_STA_STO_SLVREC_SLVTRX	((0xA0))

/** Slave transmit mode -------------------------------------------- */
/** Own SLA+R has been received, ACK has been returned */
#define I2C_I2STAT_S_TX_SLAR_ACK				((0xA8))

/** Arbitration lost in SLA+R/W as master */
#define I2C_I2STAT_S_TX_ARB_LOST_M_SLA			((0xB0))
/** Own SLA+R has been received, ACK has been returned */
//#define I2C_I2STAT_S_TX_SLAR_ACK				((0xB0))

/** Data has been transmitted, ACK has been received */
#define I2C_I2STAT_S_TX_DAT_ACK					((0xB8))
/** Data has been transmitted, NACK has been received */
#define I2C_I2STAT_S_TX_DAT_NACK				((0xC0))


/*******************************************************************************
 * @brief     Main I2C0 interrupt handler sub-routine
 * @param[in] None
 * @return    None
*******************************************************************************/
void I2C0_IRQHandler (void)
{
	uint32_t status;
	status  = I2C0->STATUS;
	if (I2C0->TOC.TIF)
	{
		REG32WRITE(I2C0->TOC,TIF,1);/* Clear TIF */      	
		if (I2CHandler0.TimeoutCallBackFn)
		{
			I2CHandler0.TimeoutCallBackFn(status); 
		}
	}
	else
	{
		switch (status)
    {	
    	case 0x38:	/* Arbitration loss */
     	{
      	if (I2CHandler0.ArbitLossCallBackFn)
				I2CHandler0.ArbitLossCallBackFn(status); 
     	  break;
     	}
 			case 0x00:	/* Bus error */
			{
        if (I2CHandler0.BusErrCallBackFn)
				I2CHandler0.BusErrCallBackFn(status); 
     	  break;
			}
			default:
			{
        if (I2CHandler0.I2CCallBackFn)
				I2CHandler0.I2CCallBackFn(status); 			
			}		
		}		
	} 
}

/*******************************************************************************
 * @brief     Main I2C1 interrupt handler sub-routine
 * @param[in] None
 * @return    None
*******************************************************************************/
void I2C1_IRQHandler(void)
{
	uint32_t status;
	status  = I2C1->STATUS;
	if (I2C1->TOC.TIF)
	{
		REG32WRITE(I2C1->TOC,TIF,1);/* Clear TIF */   	
		if (I2CHandler1.TimeoutCallBackFn)
		{
			I2CHandler1.TimeoutCallBackFn(status); 
		}
	}
	else
	{
		switch (status)
    {	
    	case 0x38:	/* Arbitration loss */
     	{
      	if (I2CHandler1.ArbitLossCallBackFn)
				I2CHandler1.ArbitLossCallBackFn(status); 
     	  break;
     	}
 			case 0x00:	/* Bus error */
			{
        if (I2CHandler1.BusErrCallBackFn)
				I2CHandler1.BusErrCallBackFn(status); 
     	  break;
			}
			default:
			{
        if (I2CHandler1.I2CCallBackFn)
				I2CHandler1.I2CCallBackFn(status); 			
			}		
		}		
	}  
}

/*******************************************************************************
 * @brief     Set I2C0 Own slave address
 * @param[in] adr  : Own slave address
 * @return    None
*******************************************************************************/
static void I2C0_Slave_SetAdr (uint8_t adr)
{
	REG32WRITE(I2C0->ADDR0,ADDR,adr);  
	REG32WRITE(I2C0->ADDR0,GC,0);	
}

/*******************************************************************************
 * @brief     Set I2C1 Own slave address
 * @param[in] adr  : Own slave address
 * @return    None
*******************************************************************************/
static void I2C1_Slave_SetAdr (uint8_t adr)
{
	REG32WRITE(I2C1->ADDR0,ADDR,adr);  
	REG32WRITE(I2C1->ADDR0,GC,0);	  
}

/*******************************************************************************
 * @brief     Initializes the I2Cx peripheral (Slave mode)
 * @param[in] I2Cx : I2C peripheral selected, should be I2C0, I2C1 
 * @param[in] adr  : Own slave address
 * @return    Result, should be
 *              -COX_SUCCESS : Success
 *              -COX_ERROR : Error occurred
*******************************************************************************/
static COX_Status I2C_Slave_Init (I2C_T *I2Cx, uint8_t adr)
{
	if(I2Cx == I2C0)
	{
		REG32WRITE(SYSCLK->APBCLK,I2C0_EN,1);    /*I2C Clock Enable*/
		REG32WRITE(SYS->IPRSTC2,I2C0_RST,1);/*IP set*/
		REG32WRITE(SYS->IPRSTC2,I2C0_RST,0);
		REG32WRITE(I2C0->CON,ENSI,1);	 /*I2C control enable*/

    /* Set Pin */
		REG32WRITE(SYS->GPAMFP,I2C0_SDA,1);
		REG32WRITE(SYS->GPAMFP,I2C0_SCL,1);

    i2c_slave_cfg[0].write_cnt = 0;
    i2c_slave_cfg[0].read_cnt = 0;    
    i2c_slave_cfg[0].cbWrite = COX_NULL;
    i2c_slave_cfg[0].cbRead = COX_NULL;
	}
	else if(I2Cx == I2C1)
	{
		REG32WRITE(SYSCLK->APBCLK,I2C1_EN,1);    /*I2C Clock Enable*/
		REG32WRITE(SYS->IPRSTC2,I2C1_RST,1);/*IP set*/
		REG32WRITE(SYS->IPRSTC2,I2C1_RST,0);
		REG32WRITE(I2C1->CON,ENSI,1);	 /*I2C control enable*/

    /* Set Pin */
		REG32WRITE(SYS->GPAMFP,I2C1_SDA,1);
		REG32WRITE(SYS->GPAMFP,I2C1_SCL,1);

    i2c_slave_cfg[1].write_cnt = 0;
    i2c_slave_cfg[1].read_cnt = 0;
    i2c_slave_cfg[1].cbWrite = COX_NULL;
    i2c_slave_cfg[1].cbRead = COX_NULL;
	}
	else
	{
  	return   COX_ERROR;
	}
	REG32WRITE(I2Cx->CON,AA,0);
	REG32WRITE(I2Cx->CON,STA,0);
	REG32WRITE(I2Cx->CON,ENSI,0);
	/* Set I2C Slave Address */
	if(I2Cx == I2C0)
		I2C0_Slave_SetAdr (adr);
	else 	if(I2Cx == I2C1)
		I2C1_Slave_SetAdr (adr);

	/* Enable I2C Peripheral */  
	REG32WRITE(I2Cx->CON,ENSI,1);

	REG32WRITE(I2Cx->CON,AA,1);
	REG32WRITE(I2Cx->CON,STA,0);
	REG32WRITE(I2Cx->CON,SI,0);
	return COX_SUCCESS;
}



/*******************************************************************************
 * @brief     Set I2C0 callback function when received a byte form master
 * @param[in] write_func : Pointer to write callback funtion 
 * @return    None
*******************************************************************************/
static void I2C0_Slave_SetWrite (cbWriteFun write_func)
{  
	i2c_slave_cfg[0].cbWrite = write_func;   
}

/*******************************************************************************
 * @brief     Set I2C1 callback function when received a byte form master
 * @param[in] write_func : Pointer to write callback funtion 
 * @return    None
*******************************************************************************/
void I2C1_Slave_SetWrite (cbWriteFun write_func)
{  
  i2c_slave_cfg[1].cbWrite = write_func;  
}

/*******************************************************************************
 * @brief     Set I2C0 callback function when need send a byte to master
 * @param[in] read_func : Pointer to read callback funtion 
 * @return    None
*******************************************************************************/
static void I2C0_Slave_SetRead (cbReadFun read_func)
{  
	i2c_slave_cfg[0].cbRead = read_func;

}

/*******************************************************************************
 * @brief     Set I2C1 callback function when need send a byte to master
 * @param[in] read_func : Pointer to read callback funtion 
 * @return    None
*******************************************************************************/
static void I2C1_Slave_SetRead (cbReadFun read_func)
{  
	i2c_slave_cfg[1].cbRead = read_func;
}

/*******************************************************************************
 * @brief     Peripheral configuration 
 * @param[in] index : 
 * @param[in] arg : 
 * @return    None
*******************************************************************************/
static COX_Status I2C_Slave_Cfg (uint8_t index, uint32_t arg, uint32_t *pre_arg)
{
  return COX_ERROR;
}

/*******************************************************************************
 * @brief     Standard Interrupt handler for I2C slave peripheral
 * @param[in] I2Cx : I2C peripheral selected, should be I2C0, I2C1 or I2C2
 * @return    None
*******************************************************************************/
void I2C_Slave_Handler(uint32_t status)
{
	I2C_T *I2Cx;
	if(I2C1->STATUS == 	status)
		I2Cx = I2C1;
	else if(I2C0->STATUS == 	status)
		I2Cx = I2C0;
	if ((status == 0x60) || (status == 0x68))	  	/* SLA+W has been received and ACK has been returned */
	{	
		REG32WRITE(I2Cx->CON,SI,1);	
		REG32WRITE(I2Cx->CON,AA,1);	
	}	
	else if (status == 0x80)					  	/* DATA has been received and ACK has been returned */
	{	 		
		REG32WRITE(I2Cx->CON,SI,1);	
		REG32WRITE(I2Cx->CON,AA,1);	
	}	
	else if ((status == 0xB0) || (status == 0xA8))  /* SLA+R has been received and ACK has been returned */
	{	
		REG32WRITE(I2Cx->CON,SI,1);	
		REG32WRITE(I2Cx->CON,AA,1);	
	}												
	else if (status == 0xC0)						/* DATA has been transmitted and NACK has been received */
	{
		REG32WRITE(I2Cx->CON,SI,1);	
		REG32WRITE(I2Cx->CON,AA,1);	
	}
	else if (status == 0xA0)						/* STOP or Repeat START has been received */
	{	
		REG32WRITE(I2Cx->CON,SI,1);	
		REG32WRITE(I2Cx->CON,AA,1);	
	}
	else
	{
		;
	}	
}


/*******************************************************************************
 * @brief     Initializes the I2C0 peripheral (Slave mode)
 * @param[in] adr  : Own slave address
 * @return    Result, should be
 *              -COX_SUCCESS 
 *              -COX_ERROR
*******************************************************************************/
static COX_Status I2C0_Slave_Init  (uint8_t adr)
{
	return I2C_Slave_Init(I2C0, adr);  
}

/*******************************************************************************
 * @brief     Initializes the I2C1 peripheral (Slave mode)
 * @param[in] adr  : Own slave address
 * @return    Result, should be
 *              -COX_SUCCESS 
 *              -COX_ERROR
*******************************************************************************/
static COX_Status I2C1_Slave_Init  (uint8_t adr)
{
	return I2C_Slave_Init(I2C1, adr);  
}

/*******************************************************************************
 * Define NUC1xx CoX I2C Slave Peripheral Interface based on I2C0
*******************************************************************************/
COX_SI2C_PI pi_i2c0_slave = 
{
  I2C0_Slave_Init,
  I2C0_Slave_SetAdr,
  I2C0_Slave_SetWrite,
  I2C0_Slave_SetRead,
  I2C_Slave_Cfg
};

/*******************************************************************************
 * Define NUC1xx CoX I2C Slave Peripheral Interface based on I2C1
*******************************************************************************/
COX_SI2C_PI pi_i2c1_slave = 
{
	I2C1_Slave_Init,
  I2C1_Slave_SetAdr,
  I2C1_Slave_SetWrite,
  I2C1_Slave_SetRead,
  I2C_Slave_Cfg
};



int32_t I2C_InstallCallback(I2C_T *port, E_I2C_CALLBACK_TYPE Type, I2C_CALLBACK callbackfn)
{
	if (port == I2C0)
	{	
		switch(Type)
    	{
        	case I2CFUNC:
        	{
            	I2CHandler0.I2CCallBackFn = callbackfn;  
        		break;
        	}
        	case ARBITLOSS:
        	{
            	I2CHandler0.ArbitLossCallBackFn = callbackfn;  
        		break;
        	}
        	case BUSERROR:
        	{
            	I2CHandler0.BusErrCallBackFn = callbackfn;  
        		break;
        	}        
        	case TIMEOUT:
        	{
            	I2CHandler0.TimeoutCallBackFn = callbackfn;  
        		break;
        	}
			default:
				return E_DRVI2C_ERR_ARGUMENT;                             	
		}
	}
	else if (port == I2C1)
	{	
		switch(Type)
    	{
        	case I2CFUNC:
        	{
            	I2CHandler1.I2CCallBackFn = callbackfn;  
        		break;
        	}
        	case ARBITLOSS:
        	{
            	I2CHandler1.ArbitLossCallBackFn = callbackfn;  
        		break;
        	}
        	case BUSERROR:
        	{
            	I2CHandler1.BusErrCallBackFn = callbackfn;  
        		break;
        	}        
        	case TIMEOUT:
        	{
            	I2CHandler1.TimeoutCallBackFn = callbackfn;  
        		break;
        	}
			default:
				return E_DRVI2C_ERR_ARGUMENT;                             	
		}
	}		
	return 0;
}


