/***************************************************************************//**
 * @file      : NUC_serial.h
 * @brief     : NUC1xx Serial Peripheral Interface
 * @version   : V1.0
 * @date      : 8. Jul. 2010
 * @author    : CooCox
*******************************************************************************/
#ifndef __NUC_SERIAL_H                                                        
#define __NUC_SERIAL_H

#include "cox_serial.h"
/**
 * Pin assignment                                                             \n
 *   +--------------+----------------+---------------+                        \n
 *   |   Interface  |       TXD      |      RXD      |                        \n
 *   +--------------+----------------+---------------+                        \n
 *   |    SERIAL0   |  PB.1          |  PB.0         |                        \n
 *   +--------------+----------------+---------------+                        \n
 *   |    SERIAL1   |  PB.5,         |  PB.4,        |                        \n
 *   +--------------+----------------+---------------+                        \n
 *   |    SERIAL2   |  PD.15,        |  PD.14,       |                        \n
 *   +--------------+----------------+---------------+                        \n
 *                                                                            \n
 * Configuration Support:                                                     \n
 *   COX_SERIAL_CFG_RATE : Set baudrate                                       \n
 *   COX_SERIAL_CFG_BITS : Number of data bits, should be                     \n
 *                          -5 : 5 bit data mode                              \n
 *                          -6 : 6 bit data mode                              \n
 *                          -7 : 7 bit data mode                              \n
 *                          -8 : 8 bit data mode (default)                    \n
 *   COX_SERIAL_CFG_STOP_BITS : Number of stop bits, should be                \n
 *                          -COX_SERIAL_STOPBIT_1 : 1 Stop Bits (default)     \n
 *                          -COX_SERIAL_STOPBIT_2 : 1 Stop Bits               \n
 *   COX_SERIAL_CFG_PARITY : Parity selection, should be                      \n
 *                          -COX_SERIAL_PARITY_NONE : No parity (default)     \n
 *                          -COX_SERIAL_PARITY_ODD  : Odd parity              \n
 *                          -COX_SERIAL_PARITY_EVEN : Even parity             \n
 *                          -COX_SERIAL_PARITY_SP_1 : Forced "1" stick parity \n
 *                          -COX_SERIAL_PARITY_SP_0 : Forced "0" stick parity \n
 *                                                                            \n
 * Default Configuration :                                                    \n
 *   8 bit data mode, COX_SERIAL_STOPBIT_1, COX_SERIAL_PARITY_NONE            \n
*******************************************************************************/
#define NUC_DEV_SERIAL0     { COX_PIN(1,  1), COX_PIN(1,  0) }

#define NUC_DEV_SERIAL1     { COX_PIN(1, 5 ), COX_PIN(1, 4 ) }

#define NUC_DEV_SERIAL2     { COX_PIN(3, 15), COX_PIN(3, 14) }



/** Define NUC1xx COX Serial Interface based on UART0
*******************************************************************************/
extern COX_SERIAL_PI pi_serial0;

/** Define NUC1xx COX Serial Interface based on UART1
*******************************************************************************/
extern COX_SERIAL_PI pi_serial1;

/** Define NUC1xx COX Serial Interface based on UART2
*******************************************************************************/ 
extern COX_SERIAL_PI pi_serial2;


#endif
