/**************************************************************************//**
 * @file      : WAU8822.h
 * @brief     : WAU8822
 * @version   : V1.0
 * @date      : 18. Dec. 2010
 * @author    : CooCox
*******************************************************************************/

#ifndef __WAU8822_H__
#define __WAU8822_H__

#include "cox_i2c.h"


/** WAU8822 Device Definition
*******************************************************************************/
typedef struct {
  uint8_t     adr;
  COX_I2C_PI *i2c;
} WAU_Dev;

/*******************************************************************************
 * WAU8822 Device Configuration Definition
*******************************************************************************/
#define WAU_3D_OFF            0x0000;				 /*>!  0% effect                    */
#define WAU_3D_LOW            0x0003;				 /*>!  20.01% effect                */
#define WAU_3D_MIDDLE         0x0000;				 /*>!  53.36% effect                */
#define WAU_3D_HIGH           0x000F;				 /*>!  100% effect (maximum effect) */

#define WAU_NORMAL            0x01					 /*>! normal operation              */
#define WAU_MUTE              0x00					 /*>! muted condition               */

#define WAU_ADDRESS           0x1A				 	 /*>! WAU8822 Device ID             */

/** Defined WAU8822 device interface
*******************************************************************************/
typedef struct {
  COX_Status (*Init)            (const WAU_Dev* dev);
  COX_Status (*Control_3D)      (const WAU_Dev* dev, uint16_t WAU_3D_Depth);
  COX_Status (*LHP_volume)      (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
  COX_Status (*RHP_volume)      (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
  COX_Status (*LSPKOUT_volume)  (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
  COX_Status (*RSPKOUT_volume)  (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
  COX_Status (*EQ1)             (const WAU_Dev* dev, uint16_t EQ1CF, uint16_t EQ1GC);
  COX_Status (*EQ2)             (const WAU_Dev* dev, uint16_t EQ2CF, uint16_t EQ2GC);
  COX_Status (*EQ3)             (const WAU_Dev* dev, uint16_t EQ3CF, uint16_t EQ3GC);
  COX_Status (*EQ4)             (const WAU_Dev* dev, uint16_t EQ4CF, uint16_t EQ4GC);
  COX_Status (*EQ5)             (const WAU_Dev* dev, uint16_t EQ5CF, uint16_t EQ5GC);
  COX_Status (*Write_Reg)       (const WAU_Dev* dev, uint8_t reg, uint16_t value);
  uint16_t   (*Read_Reg)        (const WAU_Dev* dev, uint8_t reg);
} WAU_AUDIO_DI;

/***************************************************************************//**
 * Define I2C functions prototype
*******************************************************************************/
COX_Status WAU_Init           (const WAU_Dev* dev);
COX_Status WAU_3D_Control     (const WAU_Dev* dev, uint16_t WAU_3D_Depth);
COX_Status WAU_LHP_volume     (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
COX_Status WAU_RHP_volume     (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
COX_Status WAU_LSPKOUT_volume (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
COX_Status WAU_RSPKOUT_volume (const WAU_Dev* dev, uint8_t volume, uint8_t mute);
COX_Status WAU_EQ1            (const WAU_Dev* dev, uint16_t EQ1CF, uint16_t EQ1GC);
COX_Status WAU_EQ2            (const WAU_Dev* dev, uint16_t EQ2CF, uint16_t EQ2GC);
COX_Status WAU_EQ3            (const WAU_Dev* dev, uint16_t EQ3CF, uint16_t EQ3GC);
COX_Status WAU_EQ4            (const WAU_Dev* dev, uint16_t EQ4CF, uint16_t EQ4GC);
COX_Status WAU_EQ5            (const WAU_Dev* dev, uint16_t EQ5CF, uint16_t EQ5GC);
COX_Status WAU_Write_Reg      (const WAU_Dev* dev, uint8_t reg, uint16_t value);
uint16_t   WAU_Read_Reg       (const WAU_Dev* dev, uint8_t reg);

/***************************************************************************//**
 * Define WAU8822 Device Driver Interface
*******************************************************************************/
extern const WAU_AUDIO_DI   di_wau;

#endif
