/**************************************************************************//**
 * @file      : di_uc1601.h
 * @brief     : SPI TEXT_LCD UC1601 Driver Interface
 * @version	  : 1.0
 * @date      : 27 NOV. 2010
 * @author    : CooCox
******************************************************************************/
#ifndef __SPI_LCD_Driver_H__
#define __SPI_LCD_Driver_H__

#include "cox_pio.h"
#include "cox_spi.h"
/**
Serial-9 mode:                                                                            \n
                                           |                                              \n
                              +------------+---------+ \n
           +----  SLK   ----- +          VDD         + \n
MCU SPI--- |----  SDA	----- +                      + \n
            	 	 	 	  +                      + \n
           	 	     +------- + WR0                  + \n
           	         |------- + WR1                  + \n
    	             |------- + CD                   + \n
            	     |------- + D1-D7                + \n
           	 	     |	 	  +                      + \n
           	 	    GND	 	  +         UC1601       + \n
           	 	 		      +                      + \n
 cs_pin    ------------------ +  CS                  + \n
         	 	 	 	 	  +                      + \n
         	 	 	VDD ----- + RTS                  + \n
         	 	 	 	 	  +                      + \n
         	 	 	GND ----- + PS1                  + \n
         	 	 	VDD ----- + PS0       VSS        + \n
         	 	 	 	 	  +------------+---------+ \n
         	 	 	 	 	  	  	  	   |


******************************************************************************************/
typedef struct
{
  uint16_t cs_pin;             /*!< Chip Select  */
  COX_PIO_PI  *pio;            /*!< PIO Peripheral Interface Used */
  COX_SPI_PI  *spi;            /*!< SPI Peripheral Interface Used */
} UC1601_Dev;
   
typedef struct
{
  void (*Init)     (const UC1601_Dev *dev);
  void (*SetPACA)  (const UC1601_Dev *dev, unsigned char PA, unsigned char CA);
  void (*Write)    (const UC1601_Dev *dev, unsigned char data);
  void (*Show)     (const UC1601_Dev *dev, unsigned char x, unsigned char y,unsigned char ascii_word);
  void (*Clear)    (const UC1601_Dev *dev);
  void (*Print)    (const UC1601_Dev *dev, unsigned char line, char *str);
} SLCD_SPI_DI;

extern const SLCD_SPI_DI di_uc1601;

#endif

