/***************************************************************************//**
 * @file      : KeyBoard.c
 * @brief     : Character KeyBoard Driver Interface
 * @version   : 1.0
 * @date      : 29. Nov. 2010
 * @author    : CooCox
*******************************************************************************/
#include "KeyBoard.h"
//#include "nuc1xx.h"
#if 1
#define software_delay
#endif

uint8_t  interrupt_flag = 0;

/********************************************************************************************************//**
 * @brief     The function is used to ISR to handle I2C0 interrupt event
 * @param[in] None
 * @return    None
************************************************************************************************************/
void KeyBoard_IRQHandler(void)
{
	if(1 == interrupt_flag)
		;//;printf("INT\n");
}

/***************************************************************************//**
 * @brief      Initializes the KeyBoard Pin. 
 * @param[in]  KeyBoard_Pin Struct 
 * @return     The KeyBoard  Initializes Response: 
 *               - COX_ERROR: Init failed
 *               - COX_SUCCESS: Init succeed 
*******************************************************************************/
COX_Status KeyBoard_Init(const KeyBoard_PinConfig *Key)
{	
  /* Set Key pin as Quasi-bidirectional mode */
	uint8_t i;
	for(i = 0;i<Key->matrix_width;i++)							 /* Set Key width pin as Quasi-bidirectional mode */
	{	
		Key->pio->Init(Key->width_arry_pin[i]);
		Key->pio->Dir(Key->width_arry_pin[i], 0);
		Key->pio->Dir(Key->width_arry_pin[i], 3);
	}
	for(i = 0;i<Key->matrix_high;i++)								 /* Set Key high pin as Quasi-bidirectional mode */
	{	
		Key->pio->Init(Key->high_arry_pin[i]);
		Key->pio->Dir(Key->high_arry_pin[i], 0);
		Key->pio->Dir(Key->high_arry_pin[i], 3);
	}
	return 	COX_SUCCESS;
}

/***************************************************************************//**
 * @brief      Set all the port .
 * @param[in]  KeyBoard_Pin Struct
 * @return     The Key Press Down or not:
 *               - COX_ERROR:  not key Press Down
 *               - COX_SUCCESS:  Press Down .
*******************************************************************************/
COX_Status SetAllIOPort(const KeyBoard_PinConfig *Key,uint32_t portvalue)
{
	uint8_t width = 0,high = 0;
	uint8_t temp;
	for(high=0;high<Key->matrix_high;high++)
	{
		temp = 0x01 & (portvalue >> (Key->matrix_width+high));
		Key->pio->Out(Key->high_arry_pin[high],temp);
	}
	for(width = 0;width <Key->matrix_width;width++)
	{
		temp = 1&(portvalue>>(Key->matrix_width-width-1));
		Key->pio->Out(Key->width_arry_pin[width],temp);
	}
	return COX_SUCCESS;
}

/***************************************************************************//**
 * @brief      Set all the port .
 * @param[in]  KeyBoard_Pin Struct
 * @return     The Key Press Down or not:
 *               - COX_ERROR:  not key Press Down
 *               - COX_SUCCESS:  Press Down .
*******************************************************************************/
uint32_t GetAllIOPort(const KeyBoard_PinConfig *Key)
{
	uint8_t width = 0,high = 0;
	uint32_t allport =0;
	for(high=0;high<Key->matrix_high;high++)
	{
		if(Key->pio->Read(Key->high_arry_pin[high]))
		{
			allport |= (1<<(Key->matrix_width+high));
		}
	}
	for(width = 0;width <Key->matrix_width;width++)
	{
		if(Key->pio->Read(Key->width_arry_pin[width]))
		{
			allport |= (1<<(Key->matrix_width - width-1));
		}
	}
	return allport;
}

/***************************************************************************//**
 * @brief      Scan the KeyBoard . 
 * @param[in]  KeyBoard_Pin Struct
 * @return     The KeyBoard pin Number.
*******************************************************************************/
uint32_t ScanKeyBoard_Position(const KeyBoard_PinConfig *Key)
{
	uint8_t width = 0,high = 0;
	uint16_t high_width_pin = 0;
	uint32_t port = 0;
//	uint32_t count[3] ={0x37,0x2f,0x1f};
	uint32_t count[Key->matrix_high];

	for(width=0;width<(Key->matrix_width +Key->matrix_high);width++)
	{
		port |= (1<<width);
	}
	for(width=0;width<Key->matrix_high;width++)
	{
		count[width]= port &(~((uint32_t)(1<<(Key->matrix_width+width))));
	}

	for(high = 0;high<Key->matrix_high;high++)
	{
		SetAllIOPort(Key, count[high]);
		for(width = 0;width <Key->matrix_width;width++)
		{
			if( Key->pio->Read(Key->width_arry_pin[width])==0)
			{
				high_width_pin = high*Key->matrix_width +width+1;
				return high_width_pin;
			}
		}
		//Key->pio->Out(Key->high_arry_pin[high],1);		/*Set one high pin as high level,reset it */
	}
	return 0;
}


/***************************************************************************//**
 * @brief      Scan the KeyBoard .
 * @param[in]  KeyBoard_Pin Struct
 * @return     The Key Press Down or not:
 *               - COX_ERROR:  not key Press Down
 *               - COX_SUCCESS:  Press Down .
*******************************************************************************/
COX_Status ScanKeyBoard(const KeyBoard_PinConfig *Key)
{
	uint8_t width = 0;
	uint32_t port = 0;
//	width = Key->matrix_width;
	for(width=0;width<Key->matrix_width;width++)
	{
		port |= (1<<width);
	}
	SetAllIOPort(Key, port);
	if(GetAllIOPort(Key) != port)
		return COX_SUCCESS;

	return 	COX_ERROR;
}

/***************************************************************************//**
 * Defined KeyBoard device interface
*******************************************************************************/
const KeyBoard KeyB = {
	KeyBoard_Init,							/*!< Initializes the KeyBoard Pin */
	ScanKeyBoard_Position,					/*!< Scan the KeyBoard Position */
	ScanKeyBoard,							/*!< Scan the KeyBoard key press down or not */
};


