/***************************************************************************//**
 * @file      : seven_segment.c
 * @brief     : Character Seven_Segment Driver Interface
 * @version   : 1.0
 * @date      : 8. Nuv. 2010
 * @author    : CooCox
*******************************************************************************/
#include "seven_segment.h"


static void Seven_Segment_Init(const S_Segment_Dev *segment);
static void Seven_Segment_Clear (const S_Segment_Dev *segment);
static void Seven_Segment_Show (const S_Segment_Dev *segment, uint16_t seg_com, uint8_t seg_num);

/***************************************************************************//**
 * @brief     Initializes  the Segment 
 * @param[in] segment : Seven_Segment device selected  
 * @return    None
*******************************************************************************/
static void Seven_Segment_Init (const S_Segment_Dev *segment)
{

  segment->pio->Init   (segment->pin_a); 
  segment->pio->Init   (segment->pin_b); 
  segment->pio->Init   (segment->pin_c); 
  segment->pio->Init   (segment->pin_d); 
  segment->pio->Init   (segment->pin_e); 
  segment->pio->Init   (segment->pin_f);   
  segment->pio->Init   (segment->pin_g); 
  segment->pio->Init   (segment->pin_h); 
   
  segment->pio->Init   (segment->pin_com0); 
  segment->pio->Init   (segment->pin_com1); 		
  segment->pio->Init   (segment->pin_com2);
  segment->pio->Init   (segment->pin_com3);
  
        
}

/***************************************************************************//**
 * @brief     close the Seven_Segment 
 * @param[in] segment : Seven_Segment device selected   
 * @return    None
*******************************************************************************/
static void Seven_Segment_Clear (const S_Segment_Dev *segment)
{
  segment->pio->Dir(segment->pin_com0, SEVEN_SEGMENT_CLOSE);
  segment->pio->Dir(segment->pin_com1, SEVEN_SEGMENT_CLOSE);
  segment->pio->Dir(segment->pin_com2, SEVEN_SEGMENT_CLOSE);
  segment->pio->Dir(segment->pin_com3, SEVEN_SEGMENT_CLOSE);
}

/***************************************************************************//**
 * @brief     Show the number on the Seven_Segment 
 * @param[in] segment : Seven_Segment device selected  
 * @return    None
*******************************************************************************/
static void Seven_Segment_Show (const S_Segment_Dev *segment, uint16_t seg_com, uint8_t seg_num)
{  
  unsigned char temp;
  temp = seg_num;
    
  if(((temp>>COX_PIN_NUM(segment->pin_a))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_a, 1);
  else
	segment->pio->Out   (segment->pin_a, 0);

  if(((temp>>COX_PIN_NUM(segment->pin_b))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_b, 1);
  else
	segment->pio->Out   (segment->pin_b, 0);			 

  if(((temp>>COX_PIN_NUM(segment->pin_c))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_c, 1);
  else
	segment->pio->Out   (segment->pin_c, 0);
	
  if(((temp>>COX_PIN_NUM(segment->pin_d))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_d, 1);
  else
	segment->pio->Out   (segment->pin_d, 0);
	
  if(((temp>>COX_PIN_NUM(segment->pin_e))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_e, 1);
  else
	segment->pio->Out   (segment->pin_e, 0);
	
  if(((temp>>COX_PIN_NUM(segment->pin_f))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_f, 1);
  else
	segment->pio->Out   (segment->pin_f, 0);
	
  if(((temp>>COX_PIN_NUM(segment->pin_g))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_g, 1);
  else
	segment->pio->Out   (segment->pin_g, 0);

  if(((temp>>COX_PIN_NUM(segment->pin_h))&(0x01))==0x01)		   		   
	segment->pio->Out   (segment->pin_h, 1);
  else
	segment->pio->Out   (segment->pin_h, 0);
					  				  
  segment->pio->Dir(seg_com, SEVEN_SEGMENT_OPEN);	
   
}


/***************************************************************************//**
 * Define Seven_Segment Device Driver Interface
 ******************************************************************************/
const SEVEN_SEGMENT_DI KW1_561ASB = {
  Seven_Segment_Init,
  Seven_Segment_Clear,
  Seven_Segment_Show
};
