/***************************************************************************//**
 * @file      : seven_segment.h
 * @brief     : Character seseven_segment Driver Interface
 * @version   : 1.0
 * @date      : 8. Nov. 2010
 * @author    : CooCox
*******************************************************************************/
#ifndef __IO_seven_segment_H
#define __IO_seven_segment_H

#include "cox_types.h"
#include "cox_pio.h"


/**
              +----------------------------------------------------------------+  \n
		      +    A  B     C  D
			  +   _|__|__|__|__|_	_____________ 	_____________ 	_____________ 
pin_a A 	  +   |	 _______	|   |			|	|			|	|			|
pin_b B       +   | |	C	|	|	|			|	|			|	|			|
pin_c C       +   | |B		|D  |   |			|	|			|	|			|
pin_d D		  +   |	|_______|	|   |			|	|			|	|			|
pin_e E		  +   |	|	A	|	|   |  			|	|  			|	|			|
pin_f F		  +   |	|E		|G  |	|			|	|			|	|			|
pin_g G		  +   |	|_______|.H |	|			|	|			|	|			|
pin_h H		  +   |		F		|	|			|	|			|	|			|
pin_com0 Com0 +   |_____________|	|___________|	|___________|	|___________|
pin_com1 Com1 +    |  |	 |	|  |		  |				  | 			  |
pin_com2 Com2 +    E  F COM3 G  H		 COM2 			 COM1			 COM0		
pin_com3 Com3 +
			  +----------------------------------------------------------------+  \n
																				  \n			 

 -A-H 	: 	 The seven_segment working pins
 
 -COM0-COM3 :	Pins control seven_segment to be work 	 
********************************************************************************/


#define SEVEN_SEGMENT_OPEN                 1
#define SEVEN_SEGMENT_CLOSE                0


typedef struct {
  COX_PIO_PI *pio;     /*!< The PIO Peripheral Interface used */
  uint16_t pin_a;          
  uint16_t pin_b;         
  uint16_t pin_c;          
  uint16_t pin_d;          
  uint16_t pin_e;          
  uint16_t pin_f;          
  uint16_t pin_g;      
  uint16_t pin_h;      
  uint16_t pin_com0;      
  uint16_t pin_com1;      
  uint16_t pin_com2;      
  uint16_t pin_com3;         
} S_Segment_Dev;               /* Seven_Segment Structure */

/** Defined Segment device interface
*******************************************************************************/
typedef struct {
  void (*Init)    (const S_Segment_Dev *segment);
  void (*Clear)   (const S_Segment_Dev *segment);
  void (*Show)    (const S_Segment_Dev *segment, uint16_t seg_com, uint8_t seg_num);

} SEVEN_SEGMENT_DI;

extern const SEVEN_SEGMENT_DI KW1_561ASB;

#endif
