/**
  *****************************************************************************
  * @title   nuc140-LB board CoOS application
  * @author  CooCox
  * @date    Jan 09 2011
  * @brief   A simple example shows how to use CoOS on nuc140-LB board.
  * In this CoOS example all the components are COX components,that can
  * achieve a calendar system, which show in a 128*64 LCD
  * and can set the time and alarm, the keyboard through the matrix to
  * achieve these settings, the first in the digital display key values,
  * the latter three show the value of AD conversion.
  *******************************************************************************
  */

/*---------------------------- Inlcude ---------------------------------------*/
#include <CoOS.h>			                 /*!< CoOS header file            */
#include "DrvSYS.h"

#include "seven_segment.h"
#include "NUC1xx_PIO.h"

#include "di_uc1601.h"
#include "nuc_spi_master.h"

#include"NUC1xx_RTC.h"
#include "nuc_pwm.h"
#include "nuc_adc.h"


#include "KeyBoard.h"
#include"di_w25xx.h"

#define BUF_SIZE 256
uint8_t wbuf[BUF_SIZE];
uint8_t rbuf[BUF_SIZE];
uint8_t time_alarm=0;
uint8_t alarm_again=0;
uint8_t alarming=0;

W25XX_Dev FLASH0={  COX_PIN(3,0),            /* Chip select: GPIOD0           */
		            &pi_pio,                 /* PIO Interface                 */
		            &pi_spi2,                /* SPI Interface                 */
                 };
UC1601_Dev lcd = {
		COX_PIN(3,8),                        /* Chip select: GPIOD8           */
		&pi_pio,                             /* PIO Interface                 */
		&pi_spi3                             /* SPI Interface                 */
};

COX_ADC_PI *adc = &pi_adc;                   /* ADC Interface                 */



KeyBoard_PinConfig MatrixConfig =
{
	3,
	{0x02,0x01,0x00},
	3,
	{0x03,0x04,0x05},
	&pi_pio,                                 /* PIO Interface used 		      */
};

/*---------------------------- Symbol Define ---------------------------------*/
#define STACK_SIZE_TASKA 128                 /*!< Define "taskA" task size    */
#define STACK_SIZE_TASKB 128                 /*!< Define "taskB" task size    */
#define STACK_SIZE_TASKC 128                 /*!< Define "taskC" task size    */
#define STACK_SIZE_TASKD 128                 /*!< Define "taskD" task size    */
#define STACK_SIZE_TASKE 128                 /*!< Define "taskE" task size    */
#define STACK_SIZE_TASKF 128                 /*!< Define "taskF" task size    */
#define TASK_STK_SIZE    128                 /*!< Define "task_init" task size*/


#define SEG_N0   0x82                        /*!< Segment of number 0         */
#define SEG_N1   0xEE                        /*!< Segment of number 1         */
#define SEG_N2   0x07                        /*!< Segment of number 2         */
#define SEG_N3   0x46                        /*!< Segment of number 3         */
#define SEG_N4   0x6A                        /*!< Segment of number 4         */
#define SEG_N5   0x52                        /*!< Segment of number 5         */
#define SEG_N6   0x12                        /*!< Segment of number 6         */
#define SEG_N7   0xE6                        /*!< Segment of number 7         */
#define SEG_N8   0x02                        /*!< Segment of number 8         */
#define SEG_N9   0x62                        /*!< Segment of number 9         */

unsigned char SEG_BUF[10]={SEG_N0, SEG_N1, SEG_N2, SEG_N3, SEG_N4, SEG_N5, SEG_N6, SEG_N7, SEG_N8, SEG_N9};

/*---------------------------- Variable Define -------------------------------*/
OS_STK     taskA_stk[STACK_SIZE_TASKA];	     /*!< Define "taskA" task stack   */
OS_STK     taskB_stk[STACK_SIZE_TASKB];	     /*!< Define "taskB" task stack   */
OS_STK     taskC_stk[STACK_SIZE_TASKC];	     /*!< Define "taskC" task stack   */
OS_STK     taskD_stk[STACK_SIZE_TASKD];	     /*!< Define "taskD" task stack   */
OS_STK     taskE_stk[STACK_SIZE_TASKE];	     /*!< Define "taskE" task stack   */
OS_STK     taskF_stk[STACK_SIZE_TASKF];	     /*!< Define "taskF" task stack   */
OS_STK     task_init_Stk[STACK_SIZE_TASKF];	 /*!< Define "task_init" task stack*/

OS_MutexID mut_lcd;		                     /*!< Save id of mutex.           */
OS_TID     lcd_blink_id = 0; 	             /*!< Save id of 'lcd_blink' task.*/
OS_TCID    sftmr=0xff;                       /*!< Save id of soft timer       */

OS_FlagID  rtc_flag;                         /*!< Save id of RTC flag         */
OS_FlagID  clock_flag;                       /*!< Save id of clock flag       */
OS_FlagID  time_add_flag;                    /*!< Save id of time add flag    */
OS_FlagID  time_sel_flag;                    /*!< Save id of time sel flag    */
OS_FlagID  shift_flag;                       /*!< Save id of shift flag       */
OS_FlagID  time_display_flg;                 /*!< Save id of time display flag*/
OS_FlagID  alarm_display_flg;                /*!< Save id of aiarm display flag*/
OS_FlagID  lcd_blink_flg;                    /*!< Save id of LCD blink flag   */

unsigned char 	errinfo[30];	   		     /*!< Error information.          */
unsigned char timeflag = 0;

//S_Segment_Dev defineseg ={&pi_pio,0x100,0x100,0x100,0x100,0x100,0x100,0x100,0x100,0x100,0x100,0x100,0x100};

const S_Segment_Dev nuc_lb_002 = {
	&pi_pio,                                 // Using GPIO Interface
	COX_PIN(4, 7),                           // pin_a
	COX_PIN(4, 2),                           // pin_b
	COX_PIN(4, 3),                           // pin_c
	COX_PIN(4, 4),                           // pin_d
	COX_PIN(4, 6),                           // pin_e
	COX_PIN(4, 5),                           // pin_f
	COX_PIN(4, 0),                           // pin_g
	COX_PIN(4, 1),                           // pin_h
	COX_PIN(2, 4),                           // pin_com0
	COX_PIN(2, 5),                           // pin_com1
	COX_PIN(2, 6),                           // pin_com2
	COX_PIN(2, 7),                           // pin_com3
};

COX_PIO_Dev BUZZER = NUC_PWM_CHANNEL4;       /*!< PWM channel 4 for buzzer    */
COX_PWM_PI *pwm =&pi_pwm;                    /*!<PWM Interface                */

Time Alarm_tm = {
	00,
	00,
	17,
	14,
	01,
	2011
};

Time tm = {
	00,
	59,
	16,
	14,
	01,
	2011
};

char chart1[11] = {'0','0','0','0','-','0','0','-','0','0','\0'};		/*!< Time buffer  */
char chart2[9] = {'0','0',':','0','0',':','0','0','\0'};                /*!< Date buffer  */
COX_RTC_PI *rtc = &pi_rtc;                   /*!<RTC Interface                */

/**
 *******************************************************************************
 * @brief       call back function of time Interrupt
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    Set the rtc_flag flag.
 *******************************************************************************
 */
void Periodic(void)
{
	rtc->Read(&tm);
	isr_SetFlag(rtc_flag);
}

/**
 *******************************************************************************
 * @brief       call back function of alarm Interrupt
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    Set the rtc_flag flag when alarm is enable.
 *******************************************************************************
 */
void Alarm(void)
{
	if (alarm_again != 0)
	{
		isr_SetFlag(clock_flag);
	}
}

/**
 *******************************************************************************
 * @brief       call back function of software timer
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    This task use to set the time_display_flg and clear alarm_display_flg.
 *******************************************************************************
 */
void SftTmrCallBack(void)
{
	time_alarm++;
	CoSetFlag(time_display_flg);
	CoClearFlag(alarm_display_flg);
	CoStopTmr (sftmr);

}

/**
 *******************************************************************************
 * @brief       conversion of int to char
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    The data to be displayed is converted to character array
 *******************************************************************************
 */
void Get_chart(Time *tm)
{
	chart2[7] = tm->sec%10+'0';
	chart2[6] = tm->sec/10+'0';

	chart2[4] = tm->min%10+'0';
	chart2[3] = tm->min/10+'0';

	chart2[1] = tm->hour%10+'0';
	chart2[0] = tm->hour/10+'0';

	chart1[9] = tm->mday%10+'0';
	chart1[8] = tm->mday/10+'0';

	chart1[6] = tm->mon%10+'0';
	chart1[5] = tm->mon/10+'0';

	chart1[3] = ((tm->year%1000)%100)%10+'0';
	chart1[2] = ((tm->year%1000)%100)/10+'0';
	chart1[1] = (tm->year%1000)/100+'0';
	chart1[0] = tm->year/1000+'0';
}

/**
 *******************************************************************************
 * @brief       "taskA" task code
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    Complete keyboard scan, digital control of dynamic display
 *******************************************************************************
 */
void taskA (void* pdata) {

	int i,j;
	uint32_t temp_key=0;
	uint32_t temp[4];
	uint32_t adc_value[10];
	//KeyB.Init(&MatrixConfig);
	i=0;
	KW1_561ASB.Init(&nuc_lb_002);
	while(1)
	{
		i=0;
		for(j=0;j<10;j++)
		{
			adc_value[j] = adc->Read(NUC_ADC_CHANNEL7);
			i=i+adc_value[j];
		}
		i= i*33;
		i=i/4095;
		if(KeyB.Scan(&MatrixConfig)==COX_SUCCESS)
		{
			temp_key = KeyB.GetKey(&MatrixConfig);
			KW1_561ASB.Clear(&nuc_lb_002);
			temp[0] = temp_key;
			KW1_561ASB.Show(&nuc_lb_002,COX_PIN(2, 4+3),(SEG_BUF[temp[3-3]]));
			if(alarming==1)
			{
				pwm->Stop(BUZZER);
				alarming = 0;
				CoEnterMutexSection(mut_lcd);
				if(temp_key ==7 && alarm_again>=2)
				{
					alarm_again = 0;
					di_uc1601.Print(&lcd,3, "Stop Ring Alarm ");
				}
				if(temp_key ==8 && alarm_again>=2)
				{
					di_uc1601.Print(&lcd,3, "Again after 1min");
					alarm_again=1;
				}
				if(alarm_again!=0)
				{
					alarm_again=1;
					di_uc1601.Print(&lcd,3, "Again after 1min");
				}
				CoLeaveMutexSection(mut_lcd);
			}
			else
			{
				if(temp_key ==1)
				{
					if(timeflag==0)
					time_alarm++;
					if(time_alarm%2)
					{
						if(sftmr ==0xff)
						{
							sftmr = CoCreateTmr(TMR_TYPE_PERIODIC,
															  3000,
															  3000,
															  SftTmrCallBack);
						}
						CoStartTmr (sftmr);
						CoSetFlag(alarm_display_flg);
						CoClearFlag(time_display_flg);
					}
					else
					{
						CoSetFlag(time_display_flg);
						CoClearFlag(alarm_display_flg);
					}
				}
				if(temp_key ==2)
				{
					CoSetFlag(time_sel_flag);
				}
				if(temp_key ==3)
				{
					CoSetFlag(time_add_flag);
				}
				CoEnterMutexSection(mut_lcd);
				if(temp_key ==7 && alarm_again>=2)
				{
					alarm_again = 0;
					di_uc1601.Print(&lcd,3, "Stop Ring Alarm ");
				}
				if(temp_key ==8 && alarm_again>=2)
				{
					di_uc1601.Print(&lcd,3, "Again after 1min");
					alarm_again=1;
				}
				CoLeaveMutexSection(mut_lcd);
			}
			while(KeyB.Scan(&MatrixConfig)==COX_SUCCESS);
		}
		temp[1] =(i%1000)/100;
		temp[2] =((i%1000)%100)/10;
		temp[3] =((i%1000)%100)%10;
		for(j=0;j<4;j++)
		{
			KW1_561ASB.Clear(&nuc_lb_002);
			if(j==2)
			{
				KW1_561ASB.Show(&nuc_lb_002,COX_PIN(2, 4+j),(SEG_BUF[temp[3-j]]&0xFD));
			}
			else
			{
				KW1_561ASB.Show(&nuc_lb_002,COX_PIN(2, 4+j),(SEG_BUF[temp[3-j]]));
			}
			CoTickDelay (1);
		}
	}
}


/**
 *******************************************************************************
 * @brief       "taskB" task code
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    This task use to Complete time and alarm display
 *******************************************************************************
 */
void taskB (void* pdata)
{
	U16 evtmp = 0;
	for (;;)
	{
		CoWaitForSingleFlag(rtc_flag, 0);
		evtmp = CoWaitForMultipleFlags((1<<alarm_display_flg)|(1<<time_display_flg),OPT_WAIT_ANY,0,&errinfo[20]);
		CoEnterMutexSection(mut_lcd);
		if (evtmp == (1<<time_display_flg))
		{
			Get_chart(&tm);
			di_uc1601.Print(&lcd,2, chart2);
			di_uc1601.Print(&lcd,1, chart1);
			di_uc1601.Print(&lcd,0, "Now time is :   ");
		}
		else if(evtmp == (1<<alarm_display_flg))
		{
			Get_chart(&Alarm_tm);
			di_uc1601.Print(&lcd,2, chart2);
			di_uc1601.Print(&lcd,1, chart1);
			di_uc1601.Print(&lcd,0, "Alarm time is:  ");
		}
		CoLeaveMutexSection(mut_lcd);
	}
}

/**
 *******************************************************************************
 * @brief       "taskF" task code
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    This function use to blink lcd,when time or alarm is in setting.
 *******************************************************************************
 */
void taskF (void* pdata)
{
	char flag = 0;
	pdata = pdata;
	for (;;)
	{
		CoWaitForSingleFlag(lcd_blink_flg,0);
		CoEnterMutexSection(mut_lcd);
		di_uc1601.Print(&lcd,2, chart2);
		di_uc1601.Print(&lcd,1, chart1);

		switch (timeflag)
		{
			case 0:
				break;
			case 1:
				if (flag == 0)
				{
					chart2[7] = '#';
					chart2[6] = '#';
					flag = 1;
				}
				else
				{
					if(time_alarm%2)
					{
						Get_chart(&Alarm_tm);
					}
					else
					{
						Get_chart(&tm);
					}
					flag = 0;
				}
				break;

			case 2:
				if (flag == 0)
				{
					if(time_alarm%2)
					{
						chart2[4] = '#';
						chart2[3] = '#';
					}
					else
					{
						chart2[4] = '#';
						chart2[3] = '#';
					}
					flag = 1;
				}
				else
				{
					if(time_alarm%2)
					{
						Get_chart(&Alarm_tm);
					}
					else
					{
						Get_chart(&tm);
					}
					flag = 0;
				}
				break;
			case 3:
				if (flag == 0)
				{
					if(time_alarm%2)
					{
						chart2[1] = '#';
						chart2[0] = '#';
					}
					else
					{
						chart2[1] = '#';
						chart2[0] = '#';
					}
					flag = 1;
				}
				else
				{
					if(time_alarm%2)
					{
						Get_chart(&Alarm_tm);
					}
					else
					{
						Get_chart(&tm);
					}
					flag = 0;
				}
				break;
			case 4:
				if (flag == 0)
				{
					if(time_alarm%2)
					{
						chart1[9] = '#';
						chart1[8] = '#';
					}
					else
					{
						chart1[9] = '#';
						chart1[8] = '#';
					}
					flag = 1;
				}
				else
				{
					if(time_alarm%2)
					{
						Get_chart(&Alarm_tm);
					}
					else
					{
						Get_chart(&tm);
					}
					flag = 0;
				}
				break;
			case 5:
				if (flag == 0)
				{
					if(time_alarm%2)
					{
						chart1[6] = '#';
						chart1[5] = '#';
					}
					else
					{
						chart1[6] = '#';
						chart1[5] = '#';
					}
					flag = 1;
				}
				else
				{
					if(time_alarm%2)
					{
						Get_chart(&Alarm_tm);
					}
					else
					{
						Get_chart(&tm);
					}
					flag = 0;
				}
				break;
			case 6:
				if (flag == 0)
				{
					if(time_alarm%2)
					{
						chart1[3] = '#';
						chart1[2] = '#';
						chart1[1] = '#';
						chart1[0] = '#';
					}
					else
					{
						chart1[3] = '#';
						chart1[2] = '#';
						chart1[1] = '#';
						chart1[0] = '#';
					}
					flag = 1;
				}
				else
				{
					if(time_alarm%2)
					{
						Get_chart(&Alarm_tm);
					}
					else
					{
						Get_chart(&tm);
					}
					flag = 0;
				}
				break;
			default: break;
		};
		CoLeaveMutexSection(mut_lcd);
		if (flag == 0)
			CoTickDelay (50);
		else
			CoTickDelay (100);
	}
}

/**
 *******************************************************************************
 * @brief       "taskE" task code
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    This task use to set the time or the alarm
 *******************************************************************************
 */
void taskE (void* pdata)
{
	static unsigned char bct = 0;			 /* Button calc 		          */
	U16 evtmp = 0;
	pdata = pdata;
	for (;;)
	{
		evtmp = CoWaitForMultipleFlags((1<<time_sel_flag)|(1<<time_add_flag),OPT_WAIT_ANY,0,&errinfo[20]);
		if(errinfo[20] != E_OK);

		if (evtmp == (1<<time_sel_flag))
		{
			bct++;
			switch (bct)
			{
				case 1:
					timeflag = 1;
					if(lcd_blink_id == 0)
						lcd_blink_id = CoCreateTask (taskF,0,1,&taskF_stk[STACK_SIZE_TASKF-1],STACK_SIZE_TASKF);

					NVIC_DisableIRQ(RTC_IRQn);
					if(time_alarm%2)
					{
						CoClearFlag(alarm_display_flg);
						CoStopTmr(sftmr);
					}
					else
					{
						CoClearFlag(time_display_flg);
					}
					CoSetFlag(lcd_blink_flg);
					break;
				case 2:
					timeflag = 2;
					break;
				case 3:
					timeflag = 3;
					break;
				case 4:
					timeflag = 4;
					break;
				case 5:
					timeflag = 5;
					break;
				case 6:
					timeflag = 6;
					break;
				case 7:
					bct = 0;
					timeflag = 0;

					CoClearFlag(lcd_blink_flg);
					if(time_alarm%2)
					{
						CoSetFlag(alarm_display_flg);
						rtc->Alarm(&Alarm_tm, Alarm);
						alarm_again = 1;

						CoEnterMutexSection(mut_lcd);
						di_uc1601.Print(&lcd,3, "Alarm is setting");
						CoLeaveMutexSection(mut_lcd);
						CoStartTmr (sftmr);
					}
					else
					{
						CoSetFlag(time_display_flg);
						rtc->Write(&tm);
					}

					NVIC_EnableIRQ(RTC_IRQn);
					break;
				default: break;
			};
			CoTickDelay(40);
			CoClearFlag(time_sel_flag);
		}
		else if(evtmp == (1<<time_add_flag))
		{
			switch (bct)
			{
				case 1:
					if(time_alarm%2)
					{
						Alarm_tm.sec++;
						if(Alarm_tm.sec>=60)
							Alarm_tm.sec = 0;
					}
					else
					{
						tm.sec++;
						if(tm.sec>=60)
							tm.sec = 0;
					}
					break;
				case 2:
					if(time_alarm%2)
					{
						Alarm_tm.min++;
						if(Alarm_tm.min>=60)
							Alarm_tm.min = 0;
					}
					else
					{
						tm.min++;
						if(tm.min>=60)
							tm.min = 0;
					}
					break;

				case 3:
					if(time_alarm%2)
					{
						Alarm_tm.hour++;
						if(Alarm_tm.hour>=24)
							Alarm_tm.hour = 0;
					}
					else
					{
						tm.hour++;
						if(tm.hour>=24)
							tm.hour = 0;
					}
					break;

				case 4:
					if(time_alarm%2)
					{
						Alarm_tm.mday++;
						if(Alarm_tm.mday>=31)
							Alarm_tm.mday = 0;
					}
					else
					{
						tm.mday++;
						if(tm.mday>=31)
							tm.mday = 0;
					}
					break;

				case 5:
					if(time_alarm%2)
					{
						Alarm_tm.mon++;
						if(Alarm_tm.mon>=13)
							Alarm_tm.mon = 0;
					}
					else
					{
						tm.mon++;
						if(tm.mon>=13)
							tm.mon = 0;
					}
					break;

				case 6:
					if(time_alarm%2)
					{

					}
					else
					{

					}
					break;
				default: break;
			}
			CoTickDelay(40);
			CoClearFlag(time_add_flag);
		}

	}
}

/**
 *******************************************************************************
 * @brief       "taskC" task code
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    This function use to ring the alarm clock.
 *******************************************************************************
 */
void taskC (void* pdata)
{

	for (;;)
	{
		CoWaitForSingleFlag(clock_flag, 0);
		pwm->Start(BUZZER);
		alarming = 1;
		alarm_again += 1;
		di_uc1601.Print(&lcd,3, "No press 7 Yes 8");
		if(alarm_again<5)
		{
			Alarm_tm.min = Alarm_tm.min + 1;
			rtc->Alarm(&Alarm_tm, Alarm);
		}
		else
		{
			alarm_again = 0;
			di_uc1601.Print(&lcd,3, "Stop Ring Alarm ");
		}
		CoTickDelay (3000);
		if(alarming==1)
		{
			pwm->Stop(BUZZER);
			alarming = 0;
		}
		CoClearFlag(clock_flag);
	}
}


/**
 *******************************************************************************
 * @brief       Initialization all the task in this application.
 * @param[in]   None
 * @param[out]  None
 * @retval      None
 * @par Description
 * @details    Initialize all the hardware ,Create all the flag and mutex in this application.
 *******************************************************************************
 */
void task_init (void* pdata)
{
	uint32_t i;
	for(i=0; i < BUF_SIZE; i++)
	{
		wbuf[i] = i & 0xFF;
		rbuf[i] = 0;
	}
	di_w25x16.Init(&FLASH0);

	di_uc1601.Init(&lcd);
	di_uc1601.Clear(&lcd);

	/* Erase the test sector */
	di_w25x16.EraseSector(&FLASH0, 0x000000);

	di_w25x16.WaitForReady(&FLASH0);

	/* Write a page of data to 0x00 */
	di_w25x16.Write(&FLASH0, 0x000000, wbuf, BUF_SIZE);
	di_w25x16.WaitForReady(&FLASH0);
	/* Read the page just written from 0x00 */
	di_w25x16.Read(&FLASH0, 0x000000, rbuf, BUF_SIZE);
	/*for(i=0; i < BUF_SIZE; i++)
	{
		if(rbuf[i] == wbuf[i])
		{
			di_uc1601.Print(&lcd,3, "  Test success  ");
		}
		else
		{
			di_uc1601.Print(&lcd,3, "  Test error    ");
		}
	}*/

  	rtc->Init();
  	rtc->Start();
  	rtc->Write(&tm);

  	rtc->Alarm(&Alarm_tm, Alarm);
  	alarm_again = 1;
  	di_uc1601.Print(&lcd,3, "Alarm is setting");
  	rtc->Event(1, Periodic, 0);
  	rtc->Event(2, Alarm, 0);

  	pwm->Init();
  	pwm->Period(BUZZER, 0.004);
  	pwm->Duty(BUZZER, 0.5);
  	pwm->Stop(BUZZER);

	adc->Init(100000);

	rtc_flag          = CoCreateFlag(1,0);
	clock_flag        = CoCreateFlag(0,0);
	time_add_flag     = CoCreateFlag(0,0);
	time_sel_flag     = CoCreateFlag(0,0);
	shift_flag        = CoCreateFlag(1,0);
	lcd_blink_flg     = CoCreateFlag(0,0);
	time_display_flg  = CoCreateFlag(0,1);
	alarm_display_flg = CoCreateFlag(0,0);

	CoCreateTask (taskA,0,0,&taskA_stk[STACK_SIZE_TASKA-1],STACK_SIZE_TASKA);
	CoCreateTask (taskB,0,1,&taskB_stk[STACK_SIZE_TASKB-1],STACK_SIZE_TASKB);
	CoCreateTask (taskC,0,2,&taskC_stk[STACK_SIZE_TASKC-1],STACK_SIZE_TASKC);
	CoCreateTask (taskE,0,3,&taskE_stk[STACK_SIZE_TASKE-1],STACK_SIZE_TASKE);


	CoExitTask();	                         /*!< Delete 'task_init' task.    */
}

/**
 *******************************************************************************
 * @brief		main function
 * @param[in] 	None
 * @param[out] 	None
 * @retval		None
 *******************************************************************************
 */
int main ()
{
	UNLOCKREG();
	SYSCLK->PWRCON.XTL12M_EN = 1;

	CoInitOS ();                             /*!< Initial CooCox CoOS         */
	/*!< Create init tasks	*/
	CoCreateTask(task_init, (void *)0, 10,&task_init_Stk[TASK_STK_SIZE-1], TASK_STK_SIZE);
	mut_lcd  = CoCreateMutex();
	CoStartOS ();			                 /*!< Start multitask	          */

	while (1);                               /*!< The code don''t reach here  */
}


